@@ -1,6 +1,6 @@
 import copy
 import struct
-from bitflags import bitflags
+from bitflags import bitflags, BitFlags
 from collections import OrderedDict
 
 
@@ -341,6 +341,10 @@ class ScalarFloatField(FloatField):
         obj[self.index: self.index + len(value)] = value
 
 
+# Convert BitFlags printing.
+BitFlags.__str__ = BitFlags.__repr__
+
+
 class BitFlagField(IntField):
     def __init__(self, name, index, length=None, byteorder=None, signed=None,
                  get_converter=None, set_converter=None, flags=None,
